## Changelog

### 2.3.0

#### New features

* Sieve filter management has been added to the core repository and has been migrated to New Admin.
* Postfix auto reply has been added to the core repository and has been migrated to New Admin.
* Added Oauth2 authentication.
* Added Webauthn (Fido2) as a second authentication method.
* New Admin have been migrated to Vue 3.

#### Fixes

* Few security fixes (see our policy https://github.com/modoboa/modoboa/security/policy).
* Removed SORBS DNSBL provider since it has been shutdown (https://www.sorbs.net/).
* Few documentation update.
* Fixed some issues with the password scheme setting

